local addonName, ChatAssistant = ...

function ChatAssistant.registerMiniMap()
  
  local LDB = LibStub ("LibDataBroker-1.1", true)
  local LDBIcon = LDB and LibStub ("LibDBIcon-1.0", true)
  local ON = "|cffff3333ChatAssistant v"  .. ChatAssistantSettings.version.."|r"  
  if ChatAssistantSettings.enabled then ON = "|cff33ff33ChatAssistant v"  .. ChatAssistantSettings.version.."|r" end

  if LDB then

    local databroker = LDB:NewDataObject ("ChatAssistant", {
      type = "data source",
      icon = "Interface\\AddOns\\ChatAssistant\\img\\ChatAssistant_bg",
      text = "0",
      
      HotCornerIgnore = true,
      
      OnClick = function (self, button)
      
        if (button == "LeftButton") then
          -- Note: Call this function twice (in a row), 
          -- there is a bug in Blizzard's code which makes the first call (after login or /reload) fail. 
          -- It opens interface options, but not on the addon's interface options, just the default interface options.           
          InterfaceOptionsFrame_OpenToCategory(addonName);
          ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
          InterfaceOptionsFrame_OpenToCategory(addonName);  

        elseif (button == "RightButton") then          
          ChatAssistant.toggle()  
          ON = "|cffff3333ChatAssistant v"  .. ChatAssistantSettings.version.."|r"         
          if ChatAssistantSettings.enabled then ON = "|cff33ff33ChatAssistant v"  .. ChatAssistantSettings.version.."|r" end        
        end

      end,       

      OnTooltipShow = function (tooltip)
        tooltip:AddLine (ON)
        tooltip:AddLine ("Left Click: Configure")
        tooltip:AddLine ("Right Click: |cff33ff33Enable|r/|cffff3333Disable|r")
      end,
    })
    
    if (databroker and not LDBIcon:IsRegistered ("ChatAssistant")) then
      LDBIcon:Register ("ChatAssistant", databroker, ChatAssistantSettings.minimap)
    end

  end

end


function ChatAssistant.loadOptions()
  ChatAssistant.panel = CreateFrame("Frame");
  ChatAssistant.panel.name = addonName
  InterfaceOptions_AddCategory(ChatAssistant.panel);
  
  ChatAssistant.panel.title = ChatAssistant.panel:CreateFontString("ChatAssistant_OPTIONS_TITLE", "ARTWORK", "GameFontNormalLarge")
  ChatAssistant.panel.title:SetPoint("TOPLEFT", 16, -16)
  ChatAssistant.panel.title:SetText(ChatAssistant.panel.name.." "..ChatAssistantSettings.version)
  
  local EnabledTxt = "|cffff3333Disabled|r"
  if ChatAssistantSettings.enabled then EnabledTxt = "|cff33ff33Enabled|r" end

    ChatAssistant.panel.enabledCB = ChatAssistant.createCheckBox(ChatAssistant.panel, EnabledTxt, "TOPLEFT", ChatAssistant.panel.title, "BOTTOMLEFT", function(self)    
    ChatAssistantSettings.enabled = self:GetChecked()
    ChatAssistant.panel.okay()
  end)
  ChatAssistant.panel.enabledCB:SetChecked(ChatAssistantSettings.enabled)

  ChatAssistant.panel.chanCheckBox = {}
  ChatAssistant.panel.chanCheckBoxTitle = ChatAssistant.createTitle(ChatAssistant.panel, "Listen to Channel:", "TOPLEFT", ChatAssistant.panel.enabledCB, "BOTTOMLEFT")
  local relFrame = ChatAssistant.panel.chanCheckBoxTitle
  local EnabledCString = ""

  for chanNum,chanName in pairs(ChatAssistant.getChannels()) do
      ChatAssistantSettings.channel[chanNum] = ChatAssistantSettings.channel[chanNum] or false
      local cb = ChatAssistant.createCheckBox(ChatAssistant.panel, chanNum..". "..chanName, "TOPLEFT", relFrame, "BOTTOMLEFT", function(self)
        ChatAssistantSettings.channel[chanNum] = self:GetChecked()
      end)

      cb:SetChecked(ChatAssistantSettings.channel[chanNum])
      table.insert(ChatAssistant.panel.chanCheckBox, cb)
      if ChatAssistantSettings.channel[chanNum] then  
        if EnabledCString == "" then EnabledCString = " "..chanNum..". "..chanName
          else EnabledCString = EnabledCString.."; "..chanNum..". "..chanName
         ChatAssistantSettings.channelListN = EnabledCString
        end      
       end
      relFrame = cb
  end
  
  if ChatAssistantSettings.enabled then 
       if EnabledCString  == "" then EnabledCString = ChatAssistantSettings.channelListN end
     else EnabledCString = " [DISABLED]" end  

  ChatAssistantSettings.channelListN = EnabledCString

  ChatAssistant.panel.chanCheckBoxTitle = ChatAssistant.createTitle(ChatAssistant.panel, "Listen to Channel:".. EnabledCString, "TOPLEFT", ChatAssistant.panel.enabledCB, "BOTTOMLEFT")  

  ChatAssistant.panel.critEditBox = {}
  ChatAssistant.panel.critTitle = ChatAssistant.createTitle(ChatAssistant.panel, "Match Criteria: ", "TOPLEFT", relFrame, "BOTTOMLEFT")
 
  ChatAssistant.panel.critAddBTN = ChatAssistant.createButton(ChatAssistant.panel, "+", "LEFT", ChatAssistant.panel.critTitle, "RIGHT", function()
    table.insert(ChatAssistantSettings.criteria, {"New", "ORCriteria1 ", " New", "ORCriteria2"})
    table.insert(ChatAssistantSettings.operator, true)
    table.insert(ChatAssistantSettings.critOn, true)
    ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
  end)
  ChatAssistant.panel.critAddBTN:SetSize(20 ,22) 

  ChatAssistant.panel.critRemoveBTN = ChatAssistant.createButton(ChatAssistant.panel, "-", "LEFT", ChatAssistant.panel.critAddBTN, "RIGHT", function()
    table.RemoveLast(ChatAssistantSettings.criteria)
    table.RemoveLast(ChatAssistantSettings.operator)
    table.RemoveLast(ChatAssistantSettings.critOn)
    ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
  end)
  ChatAssistant.panel.critRemoveBTN:SetSize(20 ,22) 

  relFrame = ChatAssistant.panel.critTitle
  for i,crit in ipairs(ChatAssistantSettings.criteria) do
  local title
  local eb
  local cb
  local operatorTxt = "                                                           OR"
  local critTxt = "                            [OFF]  "
  if (ChatAssistantSettings.critOn[i]) then critTxt = "                               OR   " end
    if i > 1 then  

      cb = ChatAssistant.createCheckBox(ChatAssistant.panel, "", "TOPLEFT", relFrame, "BOTTOMLEFT", function(self)
        ChatAssistantSettings.operator[i] = self:GetChecked()
      end)
      cb:SetChecked(ChatAssistantSettings.operator[i])

      if (ChatAssistantSettings.operator[i]) then operatorTxt = "                                                          AND" end
      ChatAssistant.panel.ANDTitle = ChatAssistant.createTitle(ChatAssistant.panel, operatorTxt, "TOPLEFT", relFrame, "LEFT")              
      cb = ChatAssistant.createCheckBox(ChatAssistant.panel, "", "TOPLEFT", ChatAssistant.panel.ANDTitle, "BOTTOMLEFT", function(self)
        ChatAssistantSettings.critOn[i] = self:GetChecked()
      end)
      cb:SetChecked(ChatAssistantSettings.critOn[i]) 
       title = ChatAssistant.createTitle(ChatAssistant.panel, critTxt, "LEFT", ChatAssistant.panel.ANDTitle, "BOTTOMLEFT")       
   else       
      title = ChatAssistant.createTitle(ChatAssistant.panel, critTxt, "LEFT", relFrame, "BOTTOMLEFT")       
      cb = ChatAssistant.createCheckBox(ChatAssistant.panel, "", "TOPLEFT", relFrame, "BOTTOMLEFT", function(self)
        ChatAssistantSettings.critOn[i] = self:GetChecked()
      end)
      cb:SetChecked(ChatAssistantSettings.critOn[i])      
     end

   eb = ChatAssistant.createEditBox(ChatAssistant.panel, table.ToString(ChatAssistantSettings.criteria[i]), "LEFT", title, "RIGHT")     
   eb:SetPoint("LEFT", title, "RIGHT", 0, 0)
   table.insert(ChatAssistant.panel.critEditBox, eb)
   relFrame = title
   
  end

  ChatAssistant.panel.autoRespTitle = ChatAssistant.createTitle(ChatAssistant.panel, "Response:", "TOPLEFT", relFrame, "BOTTOMLEFT")  
  ChatAssistant.panel.whisperCB = ChatAssistant.createCheckBox(ChatAssistant.panel, "Auto Whisper:", "TOPLEFT", ChatAssistant.panel.autoRespTitle, "BOTTOMLEFT", function(self)    
    ChatAssistantSettings.autoWhisper = self:GetChecked()
    ChatAssistant.panel.okay()
  end)
  ChatAssistant.panel.whisperCB:SetChecked(ChatAssistantSettings.autoWhisper)
  ChatAssistant.panel.whisperEditBox = ChatAssistant.createEditBox(ChatAssistant.panel, ChatAssistantSettings.whisperText, "LEFT", ChatAssistant.panel.whisperCB, "RIGHT")
  ChatAssistant.panel.whisperEditBox:SetPoint("LEFT", ChatAssistant.panel.whisperCB, "RIGHT", 152, 0)

  ChatAssistant.panel.inviteCB = ChatAssistant.createCheckBox(ChatAssistant.panel, "Invite", "TOPLEFT", ChatAssistant.panel.whisperCB, "BOTTOMLEFT", function(self)
    ChatAssistantSettings.autoInvite = self:GetChecked()
  end)
  ChatAssistant.panel.inviteCB:SetChecked(ChatAssistantSettings.autoInvite)

  ChatAssistant.panel.autoPostTitle = ChatAssistant.createTitle(ChatAssistant.panel, "Post Message In Selected Channels:", "TOPLEFT", ChatAssistant.panel.inviteCB, "BOTTOMLEFT")
  ChatAssistant.panel.autoPostCheckBox = ChatAssistant.createCheckBox(ChatAssistant.panel, "Post Enabled", "TOPLEFT", ChatAssistant.panel.autoPostTitle, "BOTTOMLEFT", 
function(self)
    ChatAssistantSettings.autoPost = self:GetChecked()
    if ChatAssistantSettings.autoPost then
      ChatAssistant.panel.okay()
      print("ChatAssistant Message Post |cff33ff33Enabled|r for: "..ChatAssistantSettings.channelListN)
      ChatAssistant.postInChannels()

	local postCB = function(_, _, reason)
	  ChatAssistant.postInChannels()
	end

	local skipCB = function(_, _, reason) end

	local offCB = function(_, _, reason)
	  ChatAssistantSettings.autoPost = ChatAssistant.panel.autoPostCheckBox:SetChecked(false)
	  ChatAssistantSettings.autoPostTicker._cancelled = true
	  print("ChatAssistant Auto Post Canceled!")
	end
      ChatAssistantSettings.autoPostTicker =  C_Timer.NewTicker(ChatAssistantSettings.autoPostDelay, function(args)
        --ChatAssistant.postInChannels() --Blizz disabled autopost
        ChatAssistant.shoPopUp("ChatAssistant: Send message?" .. "\n" .. ChatAssistantSettings.autoPostText, 11,"Send","Skip","Disable",postCB,skipCB,offCB)
      end)
    else
      print("ChatAssistant Message Post |cffff3333Disabled|r!")
      ChatAssistantSettings.autoPostTicker._cancelled = true
    end
  end)
  ChatAssistant.panel.autoPostCheckBox:SetChecked(ChatAssistantSettings.autoPost)
  ChatAssistant.panel.autoPostEditBox = ChatAssistant.createEditBox(ChatAssistant.panel, ChatAssistantSettings.autoPostText, "LEFT", ChatAssistant.panel.autoPostCheckBox, "RIGHT")
  ChatAssistant.panel.autoPostEditBox:SetPoint("LEFT", ChatAssistant.panel.autoPostCheckBox, "RIGHT", 152, 0)
  ChatAssistant.panel.autoPostSlider = ChatAssistant.createSlider(ChatAssistant.panel, 1, 600, ChatAssistantSettings.autoPostDelay, 1, "Delay Seconds", "TOPLEFT", ChatAssistant.panel.autoPostCheckBox, "BOTTOMLEFT", function(self, value)
    local newDelay = floor(value)
    ChatAssistantSettings.autoPostDelay = newDelay
    _G[self:GetName() .. 'Text']:SetText("Delay Seconds: " .. newDelay);
  end
  )
  ChatAssistant.panel.autoPostSlider.tooltipText = "Posts Supplied Message in Selected Channels At Given Interval"  
  ChatAssistant.panel.EmptyTitle = ChatAssistant.createTitle(ChatAssistant.panel, "", "TOPLEFT", ChatAssistant.panel.autoPostSlider, "BOTTOMLEFT")

  ChatAssistant.panel.saveBTN = ChatAssistant.createButton(ChatAssistant.panel, "Save", "TOPLEFT", ChatAssistant.panel.EmptyTitle, "RIGHT", function()
    ChatAssistant.panel.okay()
    ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)    
    print("ChatAssistant Configs Saved!")
  end)
  ChatAssistant.panel.saveBTN:SetSize(80 ,22)

  ChatAssistant.panel.refreshBTN = ChatAssistant.createButton(ChatAssistant.panel, "Refresh", "LEFT", ChatAssistant.panel.saveBTN, "RIGHT", function()
    ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
  end)
  ChatAssistant.panel.refreshBTN:SetSize(80 ,22) 

  ChatAssistant.panel.clearIgnoreBTN = ChatAssistant.createButton(ChatAssistant.panel, "Clear Ignore List", "LEFT", ChatAssistant.panel.refreshBTN, "RIGHT", function()
    print("ChatAssistant Clearing Ignore List...")
    ChatAssistantSettings.ignoreList = {}
    ChatAssistantSettings.ignoreListMsg = {}
  end)
  ChatAssistant.panel.clearIgnoreBTN:SetSize(150 ,22) 

  function ChatAssistant.panel.okay()      
      for i,eb in ipairs(ChatAssistant.panel.critEditBox) do
        ChatAssistantSettings.criteria[i] = eb:GetText():ToTable()
      end
      ChatAssistantSettings.whisperText = ChatAssistant.panel.whisperEditBox:GetText()
      ChatAssistantSettings.autoPostText = ChatAssistant.panel.autoPostEditBox:GetText()
      ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
  end

  function ChatAssistant.panel.default()      
      ChatAssistantSettings = ChatAssistant.defaults
      ChatAssistant.refreshInterfaceOptions(ChatAssistant.loadOptions)
  end

  function ChatAssistant.panel.refresh()

      ChatAssistant.panel.enabledCB:SetChecked(ChatAssistantSettings.enabled)

      for i,cb in ipairs(ChatAssistant.panel.chanCheckBox) do
        cb:SetChecked(ChatAssistantSettings.channel[i])
      end

      for i,eb in ipairs(ChatAssistant.panel.critEditBox) do
        eb:SetText(table.ToString(ChatAssistantSettings.criteria[i]))
      end
  
      ChatAssistant.panel.inviteCB:SetChecked(ChatAssistantSettings.autoInvite)
      ChatAssistant.panel.whisperCB:SetChecked(ChatAssistantSettings.autoWhisper)
      ChatAssistant.panel.whisperEditBox:SetText(ChatAssistantSettings.whisperText)
      ChatAssistant.panel.autoPostEditBox:SetText(ChatAssistantSettings.autoPostText)      
  end
 
end