local addonName, ns = ...

function string:Split(sep)
  if sep == nil then
    sep = "%s"
  end
  local t={}
  for str in string.gmatch(self, "([^"..sep.."]+)") do
      table.insert(t, str)
  end
  return t
end

function string:FindI(pattern)
  local p = pattern:gsub("(%%?)(.)", function(percent, letter)

    if percent ~= "" or not letter:match("%a") then
      return percent .. letter
    else
      return string.format("[%s%s]", letter:lower(), letter:upper())
    end
  end)
  return self:find(p)
end

function string:ToTable()
  local t = {}
   for word in self:gmatch("([%w\1-\127\194-\244\128-\191][^ ]+)") do
   table.insert(t, string.upper(word)) 
  end
  return t or {}
end

function table.ToString(t)
  local s = ""
  for k,v in pairs(t) do
    if s == "" then s = v
     else s = s .."".. v
   end
  end
  return s
end

function table.RemoveLast(t)
  if table.getn(t) ~= 1 then table.remove (t, table.getn(t)) end
end

function table.Length(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end

local uniquealyzer = 1;
function ns.createTitle(parent, text, point, relFrame, relPoinit)
  uniquealyzer = uniquealyzer + 1;
  local fs = parent:CreateFontString(addonName.."_PANEL_TITLE_"..uniquealyzer, "ARTWORK", "GameFontNormalLarge")
  fs:SetPoint(point, relFrame, relPoinit, 0, -10)
  fs:SetText(text)
  return fs
end

function ns.createCheckBox(parent, text, point, relFrame, relPoinit, onClick)
  uniquealyzer = uniquealyzer + 1;
  local globalName = addonName.."_CHECKBOX_"..uniquealyzer
  local cb = CreateFrame("CheckButton", globalName, parent, "ChatConfigCheckButtonTemplate") 
  _G[globalName.."Text"]:SetText(text)
  cb:SetPoint(point, relFrame, relPoinit)
  cb:SetScript("OnClick", onClick)
  return cb
end

function ns.createEditBox(parent, text, point, relFrame, relPoint)
  uniquealyzer = uniquealyzer + 1
  local eb = CreateFrame("EditBox", addonName.."_EDITBOX_"..uniquealyzer, parent, "InputBoxTemplate")
  eb:SetSize(200, 40)
  eb:SetPoint(point, relFrame, relPoint)
  eb:SetAutoFocus(false)
  eb:SetText(text)
  eb:SetCursorPosition(0)
  return eb
end

function ns.createButton(parent, text, point, relFrame, relPoinit, onClick)
  uniquealyzer = uniquealyzer + 1
  local btn = CreateFrame("Button", addonName.."_BTN_"..uniquealyzer, parent, "UIPanelButtonTemplate")
  btn:SetText(text)
  btn:SetPoint(point, relFrame, relPoinit)
  btn:SetScript("OnClick", onClick) 
  return btn
end

function ns.createSlider(parent, sliderMin, sliderMax, value, valueStep, text, point, relFrame, relPoinit, callBack)
  uniquealyzer = uniquealyzer + 1
  local slider = CreateFrame("Slider", addonName.."_SLIDER_" .. uniquealyzer, parent, "OptionsSliderTemplate")
  slider:SetEnabled(true)
  slider:Show()
  slider:SetWidth(200)
  slider:SetHeight(30)
  slider:SetPoint(point, relFrame, relPoinit, 0 , -20)
  slider:SetOrientation('HORIZONTAL')
  slider:SetValue(value)
  slider:SetValueStep(valueStep)
  slider:SetMinMaxValues(sliderMin,sliderMax);
  getglobal(slider:GetName() .. 'Low'):SetText(sliderMin); 
  getglobal(slider:GetName() .. 'High'):SetText(sliderMax); 
  getglobal(slider:GetName() .. 'Text'):SetText(text .. ": " .. value); 
  slider:SetScript("OnValueChanged", callBack)
  return slider
end


function ns.getChannels()

  local channels = {}
  local maxChannels = 10
  for i = 1, maxChannels do
    local id, chanName = GetChannelName(i);
    if (id > 0 and chanName ~= nil) then
      channels[id] = chanName
    end
  end
  return channels
  
end

function ns.removeInterfaceOptions(frameName, bParent)
  assert(type(frameName) == "string" and (type(bParent) == "boolean" or bParent == nil), 'Syntax: RemoveInterfaceOptions(frameName[, bParent])');
  
  local removeList = {};
  local nextFreeArraySpace = 1;
  
  if not(bParent) then
      removeList[frameName] = true;
  end
  
  for i=1, #INTERFACEOPTIONS_ADDONCATEGORIES do
      local v = INTERFACEOPTIONS_ADDONCATEGORIES[i];
      
      if (removeList[v.name] or (bParent and v.parent == frameName)) or (bParent and removeList[v.parent]) then
          removeList[v.name] = true;
      else         
          INTERFACEOPTIONS_ADDONCATEGORIES[nextFreeArraySpace] = INTERFACEOPTIONS_ADDONCATEGORIES[i];
          nextFreeArraySpace = nextFreeArraySpace + 1;
      end;
  end;
  
  for i=nextFreeArraySpace, #INTERFACEOPTIONS_ADDONCATEGORIES do
      INTERFACEOPTIONS_ADDONCATEGORIES[i] = nil;
  end;
  
  InterfaceAddOnsList_Update();
end

function ns.refreshInterfaceOptions(callBack)
  ns.removeInterfaceOptions(addonName, false)
  InterfaceOptionsFrame_Show() 
  callBack()
  InterfaceOptionsFrame_OpenToCategory(addonName);
  InterfaceOptionsFrame_OpenToCategory(addonName);
end

function ns.shoPopUp(text, timeout, btn1, btn2, btn3, acceptCB, cancelCB, altCB, hideOnEscape)
  uniquealyzer = uniquealyzer + 1;
  local popupName = addonName .. "_POPUP_ALERT_" .. uniquealyzer
  StaticPopupDialogs[popupName] = {
    text = text,
    button1 = btn1,
    button2 = btn2,
    button3 = btn3,
    OnAccept = acceptCB,
    OnCancel = cancelCB,
    OnAlt = altCB,
    timeout = timeout,
    whileDead = true,
    hideOnEscape = false,
    preferredIndex = 3,  
  }
  StaticPopup_Show (popupName)
end
